fn client_config(
cert_path: &str,
address: &str,
tls_domain: Option<&str>,
) -> Result<ClientTlsConfig, Box<dyn Error>>Expand description
Build the client-side TLS configuration from a file of trust anchors.
Arguments
cert_path- path to the trust anchor to verify the orchestrator againstaddress- the orchestrator address (-a), whose host names the orchestratortls_domain- the name to verify the orchestrator as, overriding the address (--tls_domain)
Returns
A tonic [ClientTlsConfig] that trusts the certificates in cert_path.
Errors
If the certificate file cannot be read or holds no PEM certificate.